You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@jmeter.apache.org by fs...@apache.org on 2016/09/28 19:04:22 UTC

svn commit: r1762699 - in /jmeter/trunk: bin/ src/core/org/apache/jmeter/report/config/ src/core/org/apache/jmeter/report/processor/graph/impl/ src/core/org/apache/jmeter/resources/

Author: fschumacher
Date: Wed Sep 28 19:04:22 2016
New Revision: 1762699

URL: http://svn.apache.org/viewvc?rev=1762699&view=rev
Log:
Fix typo (missing s)

Modified:
    jmeter/trunk/bin/reportgenerator.properties
    jmeter/trunk/src/core/org/apache/jmeter/report/config/ReportGeneratorConfiguration.java
    jmeter/trunk/src/core/org/apache/jmeter/report/processor/graph/impl/SyntheticResponseTimeDistributionGraphConsumer.java
    jmeter/trunk/src/core/org/apache/jmeter/resources/messages.properties
    jmeter/trunk/src/core/org/apache/jmeter/resources/messages_fr.properties

Modified: jmeter/trunk/bin/reportgenerator.properties
URL: http://svn.apache.org/viewvc/jmeter/trunk/bin/reportgenerator.properties?rev=1762699&r1=1762698&r2=1762699&view=diff
==============================================================================
--- jmeter/trunk/bin/reportgenerator.properties (original)
+++ jmeter/trunk/bin/reportgenerator.properties Wed Sep 28 19:04:22 2016
@@ -101,7 +101,7 @@ jmeter.reportgenerator.graph.responseTim
 jmeter.reportgenerator.graph.syntheticResponseTimeDistribution.classname=org.apache.jmeter.report.processor.graph.impl.SyntheticResponseTimeDistributionGraphConsumer
 jmeter.reportgenerator.graph.syntheticResponseTimeDistribution.title=Synthetic Response Times Distribution
 jmeter.reportgenerator.graph.syntheticResponseTimeDistribution.exclude_controllers=true
-jmeter.reportgenerator.graph.syntheticResponseTimeDistribution.property.set_satified_threshold=${jmeter.reportgenerator.apdex_satisfied_threshold}
+jmeter.reportgenerator.graph.syntheticResponseTimeDistribution.property.set_satisfied_threshold=${jmeter.reportgenerator.apdex_satisfied_threshold}
 jmeter.reportgenerator.graph.syntheticResponseTimeDistribution.property.set_tolerated_threshold=${jmeter.reportgenerator.apdex_tolerated_threshold}
 
 # Latencies Over Time graph definition

Modified: jmeter/trunk/src/core/org/apache/jmeter/report/config/ReportGeneratorConfiguration.java
URL: http://svn.apache.org/viewvc/jmeter/trunk/src/core/org/apache/jmeter/report/config/ReportGeneratorConfiguration.java?rev=1762699&r1=1762698&r2=1762699&view=diff
==============================================================================
--- jmeter/trunk/src/core/org/apache/jmeter/report/config/ReportGeneratorConfiguration.java (original)
+++ jmeter/trunk/src/core/org/apache/jmeter/report/config/ReportGeneratorConfiguration.java Wed Sep 28 19:04:22 2016
@@ -610,7 +610,7 @@ public class ReportGeneratorConfiguratio
                 REPORT_GENERATOR_KEY_TEMP_DIR_DEFAULT, File.class);
         configuration.setTempDirectory(tempDirectory);
 
-        // Load apdex statified threshold
+        // Load apdex statisfied threshold
         final long apdexSatisfiedThreshold = getRequiredProperty(props,
                 REPORT_GENERATOR_KEY_APDEX_SATISFIED_THRESHOLD,
                 REPORT_GENERATOR_KEY_APDEX_SATISFIED_THRESHOLD_DEFAULT,

Modified: jmeter/trunk/src/core/org/apache/jmeter/report/processor/graph/impl/SyntheticResponseTimeDistributionGraphConsumer.java
URL: http://svn.apache.org/viewvc/jmeter/trunk/src/core/org/apache/jmeter/report/processor/graph/impl/SyntheticResponseTimeDistributionGraphConsumer.java?rev=1762699&r1=1762698&r2=1762699&view=diff
==============================================================================
--- jmeter/trunk/src/core/org/apache/jmeter/resources/messages.properties (original)
+++ jmeter/trunk/src/core/org/apache/jmeter/resources/messages.properties Wed Sep 28 19:04:22 2016
@@ -882,7 +882,7 @@ request_data=Request Data
 reset=Reset
 reset_gui=Reset Gui
 response_save_as_md5=Save response as MD5 hash?
-response_time_distribution_satified_label=Requests having \\nresponse time <= {0}ms
+response_time_distribution_satisfied_label=Requests having \\nresponse time <= {0}ms
 response_time_distribution_tolerated_label= Requests having \\nresponse time > {0}ms and <= {1}ms
 response_time_distribution_untolerated_label=Requests having \\nresponse time > {0}ms
 response_time_distribution_failed_label=Requests in error

Modified: jmeter/trunk/src/core/org/apache/jmeter/resources/messages_fr.properties
URL: http://svn.apache.org/viewvc/jmeter/trunk/src/core/org/apache/jmeter/resources/messages_fr.properties?rev=1762699&r1=1762698&r2=1762699&view=diff
==============================================================================
--- jmeter/trunk/src/core/org/apache/jmeter/resources/messages_fr.properties (original)
+++ jmeter/trunk/src/core/org/apache/jmeter/resources/messages_fr.properties Wed Sep 28 19:04:22 2016
@@ -867,7 +867,7 @@ request_data=Donn\u00E9e requ\u00EAte
 reset=R\u00E9initialiser
 reset_gui=R\u00E9initialiser l'\u00E9l\u00E9ment
 response_save_as_md5=R\u00E9ponse en empreinte MD5
-response_time_distribution_satified_label=Requ\u00EAtes \\ntemps de r\u00E9ponse <= {0}ms
+response_time_distribution_satisfied_label=Requ\u00EAtes \\ntemps de r\u00E9ponse <= {0}ms
 response_time_distribution_tolerated_label=Requ\u00EAtes \\ntemps de r\u00E9ponse > {0}ms et <= {1}ms
 response_time_distribution_untolerated_label=Requ\u00EAtes \\ntemps de r\u00E9ponse > {0}ms
 response_time_distribution_failed_label=Requ\u00EAtes en erreur



Re: svn commit: r1762699 - in /jmeter/trunk: bin/ src/core/org/apache/jmeter/report/config/ src/core/org/apache/jmeter/report/processor/graph/impl/ src/core/org/apache/jmeter/resources/

Posted by Philippe Mouawad <ph...@gmail.com>.
Thanks

On Wed, Sep 28, 2016 at 9:04 PM, <fs...@apache.org> wrote:

> Author: fschumacher
> Date: Wed Sep 28 19:04:22 2016
> New Revision: 1762699
>
> URL: http://svn.apache.org/viewvc?rev=1762699&view=rev
> Log:
> Fix typo (missing s)
>
> Modified:
>     jmeter/trunk/bin/reportgenerator.properties
>     jmeter/trunk/src/core/org/apache/jmeter/report/config/
> ReportGeneratorConfiguration.java
>     jmeter/trunk/src/core/org/apache/jmeter/report/processor/graph/impl/
> SyntheticResponseTimeDistributionGraphConsumer.java
>     jmeter/trunk/src/core/org/apache/jmeter/resources/messages.properties
>     jmeter/trunk/src/core/org/apache/jmeter/resources/
> messages_fr.properties
>
> Modified: jmeter/trunk/bin/reportgenerator.properties
> URL: http://svn.apache.org/viewvc/jmeter/trunk/bin/
> reportgenerator.properties?rev=1762699&r1=1762698&r2=1762699&view=diff
> ============================================================
> ==================
> --- jmeter/trunk/bin/reportgenerator.properties (original)
> +++ jmeter/trunk/bin/reportgenerator.properties Wed Sep 28 19:04:22 2016
> @@ -101,7 +101,7 @@ jmeter.reportgenerator.graph.responseTim
>  jmeter.reportgenerator.graph.syntheticResponseTimeDistribut
> ion.classname=org.apache.jmeter.report.processor.graph.impl.
> SyntheticResponseTimeDistributionGraphConsumer
>  jmeter.reportgenerator.graph.syntheticResponseTimeDistribution.title=Synthetic
> Response Times Distribution
>  jmeter.reportgenerator.graph.syntheticResponseTimeDistribut
> ion.exclude_controllers=true
> -jmeter.reportgenerator.graph.syntheticResponseTimeDistribut
> ion.property.set_satified_threshold=${jmeter.reportgenerator.apdex_
> satisfied_threshold}
> +jmeter.reportgenerator.graph.syntheticResponseTimeDistribut
> ion.property.set_satisfied_threshold=${jmeter.reportgenerator.apdex_
> satisfied_threshold}
>  jmeter.reportgenerator.graph.syntheticResponseTimeDistribut
> ion.property.set_tolerated_threshold=${jmeter.reportgenerator.apdex_
> tolerated_threshold}
>
>  # Latencies Over Time graph definition
>
> Modified: jmeter/trunk/src/core/org/apache/jmeter/report/config/
> ReportGeneratorConfiguration.java
> URL: http://svn.apache.org/viewvc/jmeter/trunk/src/core/org/
> apache/jmeter/report/config/ReportGeneratorConfiguration.
> java?rev=1762699&r1=1762698&r2=1762699&view=diff
> ============================================================
> ==================
> --- jmeter/trunk/src/core/org/apache/jmeter/report/config/
> ReportGeneratorConfiguration.java (original)
> +++ jmeter/trunk/src/core/org/apache/jmeter/report/config/
> ReportGeneratorConfiguration.java Wed Sep 28 19:04:22 2016
> @@ -610,7 +610,7 @@ public class ReportGeneratorConfiguratio
>                  REPORT_GENERATOR_KEY_TEMP_DIR_DEFAULT, File.class);
>          configuration.setTempDirectory(tempDirectory);
>
> -        // Load apdex statified threshold
> +        // Load apdex statisfied threshold
>          final long apdexSatisfiedThreshold = getRequiredProperty(props,
>                  REPORT_GENERATOR_KEY_APDEX_SATISFIED_THRESHOLD,
>                  REPORT_GENERATOR_KEY_APDEX_SATISFIED_THRESHOLD_DEFAULT,
>
> Modified: jmeter/trunk/src/core/org/apache/jmeter/report/
> processor/graph/impl/SyntheticResponseTimeDistributionGraphConsumer.java
> URL: http://svn.apache.org/viewvc/jmeter/trunk/src/core/org/
> apache/jmeter/report/processor/graph/impl/SyntheticResponseTimeDistribut
> ionGraphConsumer.java?rev=1762699&r1=1762698&r2=1762699&view=diff
> ============================================================
> ==================
> --- jmeter/trunk/src/core/org/apache/jmeter/report/processor/graph/impl/
> SyntheticResponseTimeDistributionGraphConsumer.java (original)
> +++ jmeter/trunk/src/core/org/apache/jmeter/report/processor/graph/impl/
> SyntheticResponseTimeDistributionGraphConsumer.java Wed Sep 28 19:04:22
> 2016
> @@ -43,11 +43,11 @@ import org.apache.jmeter.util.JMeterUtil
>  public class SyntheticResponseTimeDistributionGraphConsumer extends
>          AbstractGraphConsumer {
>      private static final String FAILED_LABEL = JMeterUtils.getResString("
> response_time_distribution_failed_label");
> -    private static final MessageFormat SATISFIED_LABEL = new
> MessageFormat(JMeterUtils.getResString("response_time_
> distribution_satified_label"));
> +    private static final MessageFormat SATISFIED_LABEL = new
> MessageFormat(JMeterUtils.getResString("response_time_
> distribution_satisfied_label"));
>      private static final MessageFormat TOLERATED_LABEL = new
> MessageFormat(JMeterUtils.getResString("response_time_
> distribution_tolerated_label"));
>      private static final MessageFormat UNTOLERATED_LABEL = new
> MessageFormat(JMeterUtils.getResString("response_time_
> distribution_untolerated_label"));
>
> -    private long satifiedThreshold;
> +    private long satisfiedThreshold;
>      private long toleratedThreshold;
>
>      private class SyntheticSeriesSelector extends AbstractSeriesSelector {
> @@ -57,10 +57,10 @@ public class SyntheticResponseTimeDistri
>                  return Arrays.asList(FAILED_LABEL);
>              } else {
>                  long elapsedTime = sample.getElapsedTime();
> -                if(elapsedTime<=getSatifiedThreshold()) {
> -                    return Arrays.asList(SATISFIED_LABEL.format(new
> Object[] {Long.valueOf(getSatifiedThreshold())}));
> +                if(elapsedTime<=getSatisfiedThreshold()) {
> +                    return Arrays.asList(SATISFIED_LABEL.format(new
> Object[] {Long.valueOf(getSatisfiedThreshold())}));
>                  } else if(elapsedTime <= getToleratedThreshold()) {
> -                    return Arrays.asList(TOLERATED_LABEL.format(new
> Object[] {Long.valueOf(getSatifiedThreshold()), Long.valueOf(
> getToleratedThreshold())}));
> +                    return Arrays.asList(TOLERATED_LABEL.format(new
> Object[] {Long.valueOf(getSatisfiedThreshold()), Long.valueOf(
> getToleratedThreshold())}));
>                  } else {
>                      return Arrays.asList(UNTOLERATED_LABEL.format(new
> Object[] {Long.valueOf(getToleratedThreshold())}));
>                  }
> @@ -81,7 +81,7 @@ public class SyntheticResponseTimeDistri
>              public Double select(Sample sample) {
>                  if(sample.getSuccess()) {
>                      long elapsedTime = sample.getElapsedTime();
> -                    if(elapsedTime<=satifiedThreshold) {
> +                    if(elapsedTime<=satisfiedThreshold) {
>                          return Double.valueOf(0);
>                      } else if(elapsedTime <= toleratedThreshold) {
>                          return Double.valueOf(1);
> @@ -117,8 +117,8 @@ public class SyntheticResponseTimeDistri
>      protected void initializeExtraResults(MapResultData parentResult) {
>          ListResultData listResultData = new ListResultData();
>          String[] messages = new String[]{
> -                SATISFIED_LABEL.format(new Object[] {Long.valueOf(
> getSatifiedThreshold())}),
> -                TOLERATED_LABEL.format(new Object[] {Long.valueOf(getSatifiedThreshold()),
> Long.valueOf(getToleratedThreshold())}),
> +                SATISFIED_LABEL.format(new Object[] {Long.valueOf(
> getSatisfiedThreshold())}),
> +                TOLERATED_LABEL.format(new Object[] {Long.valueOf(getSatisfiedThreshold()),
> Long.valueOf(getToleratedThreshold())}),
>                  UNTOLERATED_LABEL.format(new Object[] {Long.valueOf(
> getToleratedThreshold())}),
>                  FAILED_LABEL
>          };
> @@ -132,17 +132,17 @@ public class SyntheticResponseTimeDistri
>      }
>
>      /**
> -     * @return the satifiedThreshold
> +     * @return the satisfiedThreshold
>       */
> -    public long getSatifiedThreshold() {
> -        return satifiedThreshold;
> +    public long getSatisfiedThreshold() {
> +        return satisfiedThreshold;
>      }
>
>      /**
> -     * @param satifiedThreshold the satifiedThreshold to set
> +     * @param satisfiedThreshold the satisfiedThreshold to set
>       */
> -    public void setSatifiedThreshold(long satifiedThreshold) {
> -        this.satifiedThreshold = satifiedThreshold;
> +    public void setSatisfiedThreshold(long satisfiedThreshold) {
> +        this.satisfiedThreshold = satisfiedThreshold;
>      }
>
>      /**
>
> Modified: jmeter/trunk/src/core/org/apache/jmeter/resources/
> messages.properties
> URL: http://svn.apache.org/viewvc/jmeter/trunk/src/core/org/
> apache/jmeter/resources/messages.properties?rev=
> 1762699&r1=1762698&r2=1762699&view=diff
> ============================================================
> ==================
> --- jmeter/trunk/src/core/org/apache/jmeter/resources/messages.properties
> (original)
> +++ jmeter/trunk/src/core/org/apache/jmeter/resources/messages.properties
> Wed Sep 28 19:04:22 2016
> @@ -882,7 +882,7 @@ request_data=Request Data
>  reset=Reset
>  reset_gui=Reset Gui
>  response_save_as_md5=Save response as MD5 hash?
> -response_time_distribution_satified_label=Requests having \\nresponse
> time <= {0}ms
> +response_time_distribution_satisfied_label=Requests having \\nresponse
> time <= {0}ms
>  response_time_distribution_tolerated_label= Requests having \\nresponse
> time > {0}ms and <= {1}ms
>  response_time_distribution_untolerated_label=Requests having \\nresponse
> time > {0}ms
>  response_time_distribution_failed_label=Requests in error
>
> Modified: jmeter/trunk/src/core/org/apache/jmeter/resources/
> messages_fr.properties
> URL: http://svn.apache.org/viewvc/jmeter/trunk/src/core/org/
> apache/jmeter/resources/messages_fr.properties?rev=
> 1762699&r1=1762698&r2=1762699&view=diff
> ============================================================
> ==================
> --- jmeter/trunk/src/core/org/apache/jmeter/resources/messages_fr.properties
> (original)
> +++ jmeter/trunk/src/core/org/apache/jmeter/resources/messages_fr.properties
> Wed Sep 28 19:04:22 2016
> @@ -867,7 +867,7 @@ request_data=Donn\u00E9e requ\u00EAte
>  reset=R\u00E9initialiser
>  reset_gui=R\u00E9initialiser l'\u00E9l\u00E9ment
>  response_save_as_md5=R\u00E9ponse en empreinte MD5
> -response_time_distribution_satified_label=Requ\u00EAtes \\ntemps de
> r\u00E9ponse <= {0}ms
> +response_time_distribution_satisfied_label=Requ\u00EAtes \\ntemps de
> r\u00E9ponse <= {0}ms
>  response_time_distribution_tolerated_label=Requ\u00EAtes \\ntemps de
> r\u00E9ponse > {0}ms et <= {1}ms
>  response_time_distribution_untolerated_label=Requ\u00EAtes \\ntemps de
> r\u00E9ponse > {0}ms
>  response_time_distribution_failed_label=Requ\u00EAtes en erreur
>
>
>


--- jmeter/trunk/src/core/org/apache/jmeter/report/processor/graph/impl/SyntheticResponseTimeDistributionGraphConsumer.java (original)
+++ jmeter/trunk/src/core/org/apache/jmeter/report/processor/graph/impl/SyntheticResponseTimeDistributionGraphConsumer.java Wed Sep 28 19:04:22 2016
@@ -43,11 +43,11 @@ import org.apache.jmeter.util.JMeterUtil
 public class SyntheticResponseTimeDistributionGraphConsumer extends
         AbstractGraphConsumer {
     private static final String FAILED_LABEL = JMeterUtils.getResString("response_time_distribution_failed_label");
-    private static final MessageFormat SATISFIED_LABEL = new MessageFormat(JMeterUtils.getResString("response_time_distribution_satified_label"));
+    private static final MessageFormat SATISFIED_LABEL = new MessageFormat(JMeterUtils.getResString("response_time_distribution_satisfied_label"));
     private static final MessageFormat TOLERATED_LABEL = new MessageFormat(JMeterUtils.getResString("response_time_distribution_tolerated_label"));
     private static final MessageFormat UNTOLERATED_LABEL = new MessageFormat(JMeterUtils.getResString("response_time_distribution_untolerated_label"));
 
-    private long satifiedThreshold;
+    private long satisfiedThreshold;
     private long toleratedThreshold;
 
     private class SyntheticSeriesSelector extends AbstractSeriesSelector {
@@ -57,10 +57,10 @@ public class SyntheticResponseTimeDistri
                 return Arrays.asList(FAILED_LABEL);
             } else {
                 long elapsedTime = sample.getElapsedTime();
-                if(elapsedTime<=getSatifiedThreshold()) {
-                    return Arrays.asList(SATISFIED_LABEL.format(new Object[] {Long.valueOf(getSatifiedThreshold())}));
+                if(elapsedTime<=getSatisfiedThreshold()) {
+                    return Arrays.asList(SATISFIED_LABEL.format(new Object[] {Long.valueOf(getSatisfiedThreshold())}));
                 } else if(elapsedTime <= getToleratedThreshold()) {
-                    return Arrays.asList(TOLERATED_LABEL.format(new Object[] {Long.valueOf(getSatifiedThreshold()), Long.valueOf(getToleratedThreshold())}));
+                    return Arrays.asList(TOLERATED_LABEL.format(new Object[] {Long.valueOf(getSatisfiedThreshold()), Long.valueOf(getToleratedThreshold())}));
                 } else {
                     return Arrays.asList(UNTOLERATED_LABEL.format(new Object[] {Long.valueOf(getToleratedThreshold())}));
                 }
@@ -81,7 +81,7 @@ public class SyntheticResponseTimeDistri
             public Double select(Sample sample) {
                 if(sample.getSuccess()) {
                     long elapsedTime = sample.getElapsedTime();
-                    if(elapsedTime<=satifiedThreshold) {
+                    if(elapsedTime<=satisfiedThreshold) {
                         return Double.valueOf(0);
                     } else if(elapsedTime <= toleratedThreshold) {
                         return Double.valueOf(1);
@@ -117,8 +117,8 @@ public class SyntheticResponseTimeDistri
     protected void initializeExtraResults(MapResultData parentResult) {
         ListResultData listResultData = new ListResultData();
         String[] messages = new String[]{
-                SATISFIED_LABEL.format(new Object[] {Long.valueOf(getSatifiedThreshold())}),
-                TOLERATED_LABEL.format(new Object[] {Long.valueOf(getSatifiedThreshold()), Long.valueOf(getToleratedThreshold())}),
+                SATISFIED_LABEL.format(new Object[] {Long.valueOf(getSatisfiedThreshold())}),
+                TOLERATED_LABEL.format(new Object[] {Long.valueOf(getSatisfiedThreshold()), Long.valueOf(getToleratedThreshold())}),
                 UNTOLERATED_LABEL.format(new Object[] {Long.valueOf(getToleratedThreshold())}),
                 FAILED_LABEL
         };
@@ -132,17 +132,17 @@ public class SyntheticResponseTimeDistri
     }
 
     /**
-     * @return the satifiedThreshold
+     * @return the satisfiedThreshold
      */
-    public long getSatifiedThreshold() {
-        return satifiedThreshold;
+    public long getSatisfiedThreshold() {
+        return satisfiedThreshold;
     }
 
     /**
      * @param satifiedThreshold the satifiedThreshold to set
      */
-    public void setSatifiedThreshold(long satifiedThreshold) {
-        this.satifiedThreshold = satifiedThreshold;
+    public void setSatisfiedThreshold(long satisfiedThreshold) {
+        this.satisfiedThreshold = satisfiedThreshold;
     }
 
     /**
@@ -132,17 +132,17 @@ public class SyntheticResponseTimeDistri
 
     /**
-     * @param satifiedThreshold the satifiedThreshold to set
+     * @param satisfiedThreshold the satisfiedThreshold to set
      */

Modified: jmeter/trunk/src/core/org/apache/jmeter/resources/messages.properties
URL: http://svn.apache.org/viewvc/jmeter/trunk/src/core/org/apache/jmeter/resources/messages.properties?rev=1762699&r1=1762698&r2=1762699&view=diff
==============================================================================
-- 
Cordialement.
Philippe Mouawad.